@@ -5,7 +5,7 @@
 # pylint: disable=too-few-public-methods
 # pylint: disable=too-many-ancestors
 """ Tests for search functionalty """
-from __future__ import absolute_import
+
 from datetime import datetime
 
 from django.core.cache import cache
@@ -72,16 +72,16 @@ class MockSearchTests(TestCase, SearcherMixin):
         abstract = SearchEngine("test_index_name")
         test_string = "A test string"
         with self.assertRaises(NotImplementedError):
-            abstract.index("test_doc", [{"name": test_string}])
+            abstract.index([{"name": test_string}])
         with self.assertRaises(NotImplementedError):
             abstract.search(test_string)
         with self.assertRaises(NotImplementedError):
-            abstract.remove("test_doc", ["test_id"])
+            abstract.remove(["test_id"])
 
     def test_find_all(self):
         """ Make sure that null search finds everything in the index """
         test_string = "A test string"
-        self.searcher.index("test_doc", [{"name": test_string}])
+        self.searcher.index([{"name": test_string}])
 
         # search everything
         response = self.searcher.search(None)
@@ -89,7 +89,7 @@ class MockSearchTests(TestCase, SearcherMixin):
         results = response["results"]
         self.assertEqual(results[0]["data"]["name"], test_string)
 
-        self.searcher.index("not_test_doc", [{"value": test_string}])
+        self.searcher.index([{"value": test_string}])
 
         response = self.searcher.search(None)
         self.assertEqual(response["total"], 2)
@@ -99,27 +99,10 @@ class MockSearchTests(TestCase, SearcherMixin):
         self.assertEqual(test_0["name"], test_string)
         self.assertEqual(test_1["value"], test_string)
 
-    def test_find_doctype(self):
-        """ Make sure that searches for specific doc_type only return requested doc_type """
-        test_string = "A test string"
-        self.searcher.index("test_doc", [{"name": test_string}])
-
-        # search by doc_type
-        response = self.searcher.search(None, doc_type="test_doc")
-        self.assertEqual(response["total"], 1)
-
-        response = self.searcher.search(None, doc_type="not_test_doc")
-        self.assertEqual(response["total"], 0)
-
-        self.searcher.index("not_test_doc", [{"value": test_string}])
-
-        response = self.searcher.search(None, doc_type="not_test_doc")
-        self.assertEqual(response["total"], 1)
-
     def test_find_string(self):
         """ Find a string within the object "content" node """
         test_string = "A test string"
-        self.searcher.index("test_doc", [{"content": {"name": test_string}}])
+        self.searcher.index([{"content": {"name": test_string}}])
 
         # search string
         response = self.searcher.search(test_string)
@@ -128,18 +111,15 @@ class MockSearchTests(TestCase, SearcherMixin):
         response = self.searcher.search_string(test_string)
         self.assertEqual(response["total"], 1)
 
-        self.searcher.index("not_test_doc", [{"content": {"value": test_string}}])
+        self.searcher.index([{"content": {"value": test_string}}])
 
         response = self.searcher.search_string(test_string)
         self.assertEqual(response["total"], 2)
 
-        response = self.searcher.search_string(test_string, doc_type="test_doc")
-        self.assertEqual(response["total"], 1)
-
         response = self.searcher.search_string("something else")
         self.assertEqual(response["total"], 0)
 
-        self.searcher.index("test_doc", [{"content": {"deep": {"down": test_string}}}])
+        self.searcher.index([{"content": {"deep": {"down": test_string}}}])
         response = self.searcher.search_string(test_string)
         self.assertEqual(response["total"], 3)
 
@@ -155,7 +135,7 @@ class MockSearchTests(TestCase, SearcherMixin):
             "fieldX": "valueY",
             "id": "12345"
         }
-        self.searcher.index("test_doc", [test_object])
+        self.searcher.index([test_object])
 
         # search tags
         response = self.searcher.search_fields({"tags.tag_one": "one"})
@@ -189,7 +169,7 @@ class MockSearchTests(TestCase, SearcherMixin):
             "course": "A/B/C",
             "abc": "xyz",
         }
-        self.searcher.index("test_doc", [test_object])
+        self.searcher.index([test_object])
 
         response = self.searcher.search(query_string="find me")
         self.assertEqual(response["total"], 1)
@@ -222,7 +202,7 @@ class MockSearchTests(TestCase, SearcherMixin):
             "taste": "sour",
         }
         test_object["tags"] = tags
-        self.searcher.index("test_doc", [test_object])
+        self.searcher.index([test_object])
 
         response = self.searcher.search_fields({"tags.color": "red"})
         self.assertEqual(response["total"], 1)
@@ -261,10 +241,6 @@ class MockSearchTests(TestCase, SearcherMixin):
         response = self._searcher.search(field_dictionary={"tags.shape": "square", "tags.color": "blue"})
         self.assertEqual(response["total"], 0)
 
-        response = self._searcher.search(
-            field_dictionary={"tags.shape": "square", "tags.color": "blue"}, use_field_match=True)
-        self.assertEqual(response["total"], 0)
-
     def test_search_array(self):
         """ test nested object array """
         test_object1 = {
@@ -277,8 +253,7 @@ class MockSearchTests(TestCase, SearcherMixin):
             "course_id": "C/D/E",
             "array": ["a", "b", "c"]
         }
-        self.searcher.index("test_doc", [test_object1])
-        self.searcher.index("test_doc", [test_object2])
+        self.searcher.index([test_object1, test_object2])
 
         response = self.searcher.search(field_dictionary={"array": "x"})
         self.assertEqual(response["total"], 1)
@@ -305,8 +280,7 @@ class MockSearchTests(TestCase, SearcherMixin):
             "name": "Anthony Rizzo",
             "course": "C/D/E"
         }
-        self.searcher.index("test_doc", [test_object1])
-        self.searcher.index("test_doc", [test_object2])
+        self.searcher.index([test_object1, test_object2])
 
         response = self.searcher.search(field_dictionary={"course": ["x", "y"]})
         self.assertEqual(response["total"], 0)
@@ -323,7 +297,7 @@ class MockSearchTests(TestCase, SearcherMixin):
     def test_extended_characters(self):
         """ Make sure that extended character searches work """
         test_string = u"قضايـا هامـة"
-        self.searcher.index("test_doc", [{"content": {"name": test_string}}])
+        self.searcher.index([{"content": {"name": test_string}}])
 
         # search string
         response = self.searcher.search(test_string)
@@ -332,7 +306,7 @@ class MockSearchTests(TestCase, SearcherMixin):
         response = self.searcher.search_string(test_string)
         self.assertEqual(response["total"], 1)
 
-        self.searcher.index("not_test_doc", [{"content": {"value": test_string}}])
+        self.searcher.index([{"content": {"value": test_string}}])
 
         response = self.searcher.search_string(test_string)
         self.assertEqual(response["total"], 2)
@@ -340,42 +314,41 @@ class MockSearchTests(TestCase, SearcherMixin):
     def test_delete_item(self):
         """ make sure that we can remove an item from the index """
         test_string = "This is a test of the emergency broadcast system"
-        self.searcher.index("test_doc", [{"id": "FAKE_ID", "content": {"name": test_string}}])
+        self.searcher.index([{"id": "FAKE_ID", "content": {"name": test_string}}])
 
         response = self.searcher.search(test_string)
         self.assertEqual(response["total"], 1)
-
-        self.searcher.remove("test_doc", [response["results"][0]["data"]["id"]])
+        self.searcher.remove([response["results"][0]["data"]["id"]])
         response = self.searcher.search(test_string)
         self.assertEqual(response["total"], 0)
 
     def test_delete_item_slashes(self):
         """ make sure that we can remove an item from the index with complex id """
         test_string = "This is a test of the emergency broadcast system"
-        self.searcher.index(
-            "test_doc", [
-                {
-                    "id": "i4x://edX/DemoX/google-document/e3369ea4aa0749a7ba29c461d1c819a4",
-                    "content": {"name": test_string}
-                }
-            ]
-        )
+        self.searcher.index([
+            {
+                "id": "i4x://edX/DemoX/google-document/e3369ea4aa0749a7ba29c461d1c819a4",
+                "content": {"name": test_string}
+            },
+        ])
 
         response = self.searcher.search(test_string)
         self.assertEqual(response["total"], 1)
 
-        self.searcher.remove("test_doc", ["i4x://edX/DemoX/google-document/e3369ea4aa0749a7ba29c461d1c819a4"])
+        self.searcher.remove(["i4x://edX/DemoX/google-document/e3369ea4aa0749a7ba29c461d1c819a4"])
         response = self.searcher.search(test_string)
         self.assertEqual(response["total"], 0)
 
     def test_delete_item_not_present(self):
         """ make sure that we get no error removing an item that does not exist """
-        self.searcher.remove("test_doc", ["TOTALLY_FAKE_ID"])
+        self.searcher.remove(["TOTALLY_FAKE_ID"])
 
     def test_filter_items(self):
         """ Make sure that filters work """
-        self.searcher.index("test_doc", [{"id": "FAKE_ID_1", "test_value": "1", "filter_field": "my_filter_value"}])
-        self.searcher.index("test_doc", [{"id": "FAKE_ID_2", "test_value": "2"}])
+        self.searcher.index([
+            {"id": "FAKE_ID_1", "test_value": "1", "filter_field": "my_filter_value"},
+            {"id": "FAKE_ID_2", "test_value": "2"},
+        ])
 
         response = self.searcher.search(filter_dictionary={"filter_field": "my_filter_value"})
         self.assertEqual(response["total"], 2)
@@ -383,7 +356,7 @@ class MockSearchTests(TestCase, SearcherMixin):
         response = self.searcher.search(field_dictionary={"filter_field": "my_filter_value"})
         self.assertEqual(response["total"], 1)
 
-        self.searcher.index("test_doc", [{"id": "FAKE_ID_3", "test_value": "3", "filter_field": "not_my_filter_value"}])
+        self.searcher.index([{"id": "FAKE_ID_3", "test_value": "3", "filter_field": "not_my_filter_value"}])
         response = self.searcher.search(filter_dictionary={"filter_field": "my_filter_value"})
         self.assertEqual(response["total"], 2)
 
@@ -394,9 +367,11 @@ class MockSearchTests(TestCase, SearcherMixin):
         """
         Make sure that iterable filters works
         """
-        self.searcher.index("test_doc", [{"id": "FAKE_ID_1"}])
-        self.searcher.index("test_doc", [{"id": "FAKE_ID_2", "filter_field": "orange"}])
-        self.searcher.index("test_doc", [{"id": "FAKE_ID_3", "filter_field": ["orange", "blue"]}])
+        self.searcher.index([
+            {"id": "FAKE_ID_1"},
+            {"id": "FAKE_ID_2", "filter_field": "orange"},
+            {"id": "FAKE_ID_3", "filter_field": ["orange", "blue"]},
+        ])
 
         response = self.searcher.search(filter_dictionary={"filter_field": "orange"})
         self.assertEqual(response["total"], 3)
@@ -412,9 +387,11 @@ class MockSearchTests(TestCase, SearcherMixin):
         Make sure that filtering with `None` value finds only fields where item
         is not present or where explicitly None
         """
-        self.searcher.index("test_doc", [{"id": "FAKE_ID_1", "test_value": "1", "filter_field": "my_filter_value"}])
-        self.searcher.index("test_doc", [{"id": "FAKE_ID_2", "test_value": "2"}])
-        self.searcher.index("test_doc", [{"id": "FAKE_ID_3", "test_value": "3", "filter_field": "not_my_filter_value"}])
+        self.searcher.index([
+            {"id": "FAKE_ID_1", "test_value": "1", "filter_field": "my_filter_value"},
+            {"id": "FAKE_ID_2", "test_value": "2"},
+            {"id": "FAKE_ID_3", "test_value": "3", "filter_field": "not_my_filter_value"},
+        ])
 
         response = self.searcher.search(filter_dictionary={"filter_field": "my_filter_value"})
         self.assertEqual(response["total"], 2)
@@ -422,14 +399,16 @@ class MockSearchTests(TestCase, SearcherMixin):
         response = self.searcher.search(filter_dictionary={"filter_field": None})
         self.assertEqual(response["total"], 1)
 
-        self.searcher.index("test_doc", [{"id": "FAKE_ID_4", "test_value": "4", "filter_field": None}])
+        self.searcher.index([{"id": "FAKE_ID_4", "test_value": "4", "filter_field": None}])
         response = self.searcher.search(filter_dictionary={"filter_field": None})
         self.assertEqual(response["total"], 2)
 
     def test_date_range(self):
         """ Make sure that date ranges can be searched """
-        self.searcher.index("test_doc", [{"id": "FAKE_ID_1", "test_value": "1", "start_date": datetime(2010, 1, 1)}])
-        self.searcher.index("test_doc", [{"id": "FAKE_ID_2", "test_value": "2", "start_date": datetime(2100, 1, 1)}])
+        self.searcher.index([
+            {"id": "FAKE_ID_1", "test_value": "1", "start_date": datetime(2010, 1, 1)},
+            {"id": "FAKE_ID_2", "test_value": "2", "start_date": datetime(2100, 1, 1)},
+        ])
 
         response = self.searcher.search()
         self.assertEqual(response["total"], 2)
@@ -448,9 +427,11 @@ class MockSearchTests(TestCase, SearcherMixin):
 
     def test_numeric_range(self):
         """ Make sure that numeric ranges can be searched with both field and filter queries """
-        self.searcher.index("test_doc", [{"id": "FAKE_ID_1", "test_value": "1", "age": 20}])
-        self.searcher.index("test_doc", [{"id": "FAKE_ID_2", "test_value": "2", "age": 30}])
-        self.searcher.index("test_doc", [{"id": "FAKE_ID_3", "test_value": "3", "age": 40}])
+        self.searcher.index([
+            {"id": "FAKE_ID_1", "test_value": "1", "age": 20},
+            {"id": "FAKE_ID_2", "test_value": "2", "age": 30},
+            {"id": "FAKE_ID_3", "test_value": "3", "age": 40},
+        ])
 
         def test_age_range_field(begin, end, expect):
             """ repeated operations consolidated for tests """
@@ -481,7 +462,7 @@ class MockSearchTests(TestCase, SearcherMixin):
         test_age_range_filter(None, 29, 1)
         test_age_range_filter(39, None, 1)
 
-        self.searcher.index("test_doc", [{"id": "FAKE_ID_4", "test_value": "4", "age": 50}])
+        self.searcher.index([{"id": "FAKE_ID_4", "test_value": "4", "age": 50}])
 
         test_age_range_field(19, 29, 1)
         test_age_range_field(19, 39, 2)
@@ -499,7 +480,7 @@ class MockSearchTests(TestCase, SearcherMixin):
         test_age_range_filter(None, 29, 1)
         test_age_range_filter(39, None, 2)
 
-        self.searcher.index("test_doc", [{"id": "FAKE_ID_5", "test_value": "5", "not_age": 50}])
+        self.searcher.index([{"id": "FAKE_ID_5", "test_value": "5", "not_age": 50}])
         test_age_range_filter(19, 29, 2)
         test_age_range_filter(19, 39, 3)
         test_age_range_filter(19, 49, 4)
@@ -510,9 +491,11 @@ class MockSearchTests(TestCase, SearcherMixin):
 
     def test_range_filter(self):
         """ Make sure that ranges can be used in field_dictionary and filter_dictionary """
-        self.searcher.index("test_doc", [{"id": "FAKE_ID_1", "test_value": "1", "age": 20}])
-        self.searcher.index("test_doc", [{"id": "FAKE_ID_2", "test_value": "2", "age": 30}])
-        self.searcher.index("test_doc", [{"id": "FAKE_ID_3", "test_value": "3", "not_age": 40}])
+        self.searcher.index([
+            {"id": "FAKE_ID_1", "test_value": "1", "age": 20},
+            {"id": "FAKE_ID_2", "test_value": "2", "age": 30},
+            {"id": "FAKE_ID_3", "test_value": "3", "not_age": 40},
+        ])
 
         response = self.searcher.search()
         self.assertEqual(response["total"], 3)
@@ -525,42 +508,29 @@ class MockSearchTests(TestCase, SearcherMixin):
 
     def test_pagination(self):
         """ Test paging operation """
-        self.searcher.index(
-            "test_doc",
-            [
-                {
-                    "course": "ABC",
-                    "id": "FAKE_ID_1",
-                    "content": {
-                        "text": "Little Darling Little Darling Little Darling, it's been a long long lonely winter"
-                    }
+        self.searcher.index([
+            {
+                "course": "ABC",
+                "id": "FAKE_ID_1",
+                "content": {
+                    "text": "Little Darling Little Darling Little Darling, it's been a long long lonely winter"
                 }
-            ]
-        )
-        self.searcher.index(
-            "test_doc",
-            [
-                {
-                    "course": "ABC",
-                    "id": "FAKE_ID_2",
-                    "content": {
-                        "text": "Little Darling Little Darling, it's been a year since you've been gone"
-                    }
+            },
+            {
+                "course": "ABC",
+                "id": "FAKE_ID_2",
+                "content": {
+                    "text": "Little Darling Little Darling, it's been a year since you've been gone"
                 }
-            ]
-        )
-        self.searcher.index(
-            "test_doc",
-            [
-                {
-                    "course": "XYZ",
-                    "id": "FAKE_ID_3",
-                    "content": {
-                        "text": "Little Darling, it's been a long long lonely winter"
-                    }
+            },
+            {
+                "course": "XYZ",
+                "id": "FAKE_ID_3",
+                "content": {
+                    "text": "Little Darling, it's been a long long lonely winter"
                 }
-            ]
-        )
+            },
+        ])
 
         response = self.searcher.search(query_string="Little Darling")
         self.assertEqual(response["total"], 3)
@@ -604,12 +574,14 @@ class MockSearchTests(TestCase, SearcherMixin):
 
     def test_exclude_ids(self):
         """ Test that ids that would normally be present in the resultset will not be present if in the exclude list """
-        self.searcher.index("test_doc", [{"course": "ABC", "id": "FAKE_ID_1"}])
-        self.searcher.index("test_doc", [{"course": "ABC", "id": "FAKE_ID_2"}])
-        self.searcher.index("test_doc", [{"course": "ABC", "id": "FAKE_ID_3"}])
-        self.searcher.index("test_doc", [{"course": "XYZ", "id": "FAKE_ID_11"}])
-        self.searcher.index("test_doc", [{"course": "XYZ", "id": "FAKE_ID_12"}])
-        self.searcher.index("test_doc", [{"course": "XYZ", "id": "FAKE_ID_13"}])
+        self.searcher.index([
+            {"course": "ABC", "id": "FAKE_ID_1"},
+            {"course": "ABC", "id": "FAKE_ID_2"},
+            {"course": "ABC", "id": "FAKE_ID_3"},
+            {"course": "XYZ", "id": "FAKE_ID_11"},
+            {"course": "XYZ", "id": "FAKE_ID_12"},
+            {"course": "XYZ", "id": "FAKE_ID_13"},
+        ])
 
         response = self.searcher.search()
         self.assertEqual(response["total"], 6)
@@ -621,7 +593,9 @@ class MockSearchTests(TestCase, SearcherMixin):
         self.assertIn("FAKE_ID_12", result_ids)
         self.assertIn("FAKE_ID_13", result_ids)
 
-        response = self.searcher.search(exclude_ids=["FAKE_ID_1", "FAKE_ID_2", "FAKE_ID_11", "FAKE_ID_12"])
+        response = self.searcher.search(
+            exclude_ids=["FAKE_ID_1", "FAKE_ID_2", "FAKE_ID_11", "FAKE_ID_12"]
+        )
         self.assertEqual(response["total"], 2)
         result_ids = [r["data"]["id"] for r in response["results"]]
         self.assertNotIn("FAKE_ID_1", result_ids)
@@ -653,9 +627,11 @@ class MockSearchTests(TestCase, SearcherMixin):
 
     def test_exclude_filter_single(self):
         """ Test that single entries present in the exclude filter are filtered out """
-        self.searcher.index("test_doc", [{"course": "ABC", "org": "edX", "id": "FAKE_ID_1"}])
-        self.searcher.index("test_doc", [{"course": "XYZ", "org": "edX", "id": "FAKE_ID_2"}])
-        self.searcher.index("test_doc", [{"course": "LMN", "org": "MITX", "id": "FAKE_ID_3"}])
+        self.searcher.index([
+            {"course": "ABC", "org": "edX", "id": "FAKE_ID_1"},
+            {"course": "XYZ", "org": "edX", "id": "FAKE_ID_2"},
+            {"course": "LMN", "org": "MITX", "id": "FAKE_ID_3"},
+        ])
 
         response = self.searcher.search()
         self.assertEqual(response["total"], 3)
@@ -696,11 +672,13 @@ class MockSearchTests(TestCase, SearcherMixin):
 
     def test_exclude_filter_multiple(self):
         """ Test that multiple entries present in the exclude filter are filtered out """
-        self.searcher.index("test_doc", [{"course": "ABC", "org": "edX", "id": "FAKE_ID_1"}])
-        self.searcher.index("test_doc", [{"course": "XYZ", "org": "edX", "id": "FAKE_ID_2"}])
-        self.searcher.index("test_doc", [{"course": "DEF", "org": "MITX", "id": "FAKE_ID_3"}])
-        self.searcher.index("test_doc", [{"course": "GHI", "org": "HarvardX", "id": "FAKE_ID_4"}])
-        self.searcher.index("test_doc", [{"course": "LMN", "org": "edX", "id": "FAKE_ID_5"}])
+        self.searcher.index([
+            {"course": "ABC", "org": "edX", "id": "FAKE_ID_1"},
+            {"course": "XYZ", "org": "edX", "id": "FAKE_ID_2"},
+            {"course": "DEF", "org": "MITX", "id": "FAKE_ID_3"},
+            {"course": "GHI", "org": "HarvardX", "id": "FAKE_ID_4"},
+            {"course": "LMN", "org": "edX", "id": "FAKE_ID_5"},
+        ])
 
         response = self.searcher.search()
         self.assertEqual(response["total"], 5)
@@ -756,11 +734,13 @@ class MockSearchTests(TestCase, SearcherMixin):
 
     def test_exclude_filter_empty(self):
         """ Test that search works when exclude filter is an empty list """
-        self.searcher.index("test_doc", [{"course": "ABC", "org": "edX", "id": "FAKE_ID_1"}])
-        self.searcher.index("test_doc", [{"course": "XYZ", "org": "edX", "id": "FAKE_ID_2"}])
-        self.searcher.index("test_doc", [{"course": "DEF", "org": "MITX", "id": "FAKE_ID_3"}])
-        self.searcher.index("test_doc", [{"course": "GHI", "org": "HarvardX", "id": "FAKE_ID_4"}])
-        self.searcher.index("test_doc", [{"course": "LMN", "org": "edX", "id": "FAKE_ID_5"}])
+        self.searcher.index([
+            {"course": "ABC", "org": "edX", "id": "FAKE_ID_1"},
+            {"course": "XYZ", "org": "edX", "id": "FAKE_ID_2"},
+            {"course": "DEF", "org": "MITX", "id": "FAKE_ID_3"},
+            {"course": "GHI", "org": "HarvardX", "id": "FAKE_ID_4"},
+            {"course": "LMN", "org": "edX", "id": "FAKE_ID_5"},
+        ])
 
         response = self.searcher.search(exclude_dictionary={"org": []})
         self.assertEqual(response["total"], 5)
@@ -783,83 +763,91 @@ class MockSearchTests(TestCase, SearcherMixin):
         self.assertNotIn("FAKE_ID_4", result_ids)
         self.assertIn("FAKE_ID_5", result_ids)
 
-    def _index_for_facets(self):
-        """ Prepare index for facet tests """
-        self.searcher.index("test_doc", [{"id": "FAKE_ID_1", "subject": "mathematics", "org": "edX"}])
-        self.searcher.index("test_doc", [{"id": "FAKE_ID_2", "subject": "mathematics", "org": "MIT"}])
-        self.searcher.index("test_doc", [{"id": "FAKE_ID_3", "subject": "physics", "org": "MIT"}])
-        self.searcher.index("test_doc", [{"id": "FAKE_ID_4", "subject": "history", "org": "Harvard"}])
-        self.searcher.index("test_doc", [{"id": "FAKE_ID_5", "subject": "mathematics", "org": "Harvard"}])
-        self.searcher.index("test_doc", [{"id": "FAKE_ID_6", "subject": "physics", "org": "Harvard"}])
-        self.searcher.index("test_doc", [{"id": "FAKE_ID_7", "no_subject": "not_a_subject", "org": "Harvard"}])
+    def _index_for_aggs(self):
+        """ Prepare index for aggregation tests """
+        self.searcher.index([
+            {"id": "FAKE_ID_1", "subject": "mathematics", "org": "edX"},
+            {"id": "FAKE_ID_2", "subject": "mathematics", "org": "MIT"},
+            {"id": "FAKE_ID_3", "subject": "physics", "org": "MIT"},
+            {"id": "FAKE_ID_4", "subject": "history", "org": "Harvard"},
+            {"id": "FAKE_ID_5", "subject": "mathematics", "org": "Harvard"},
+            {"id": "FAKE_ID_6", "subject": "physics", "org": "Harvard"},
+            {"id": "FAKE_ID_7", "no_subject": "not_a_subject", "org": "Harvard"},
+        ])
 
-    def test_faceted_search(self):
-        """ Test that faceting works well """
-        self._index_for_facets()
+    def test_aggregation_search(self):
+        """ Test that aggregation works well """
+        self._index_for_aggs()
 
         response = self.searcher.search()
         self.assertEqual(response["total"], 7)
-        self.assertNotIn("facets", response)
+        self.assertNotIn("aggs", response)
 
-        facet_terms = {
+        aggregation_terms = {
             "subject": {},
             "org": {}
         }
-        response = self.searcher.search(facet_terms=facet_terms)
+        response = self.searcher.search(aggregation_terms=aggregation_terms)
         self.assertEqual(response["total"], 7)
-        self.assertIn("facets", response)
-        facet_results = response["facets"]
+        self.assertIn("aggs", response)
+        aggregation_results = response["aggs"]
 
-        self.assertEqual(facet_results["subject"]["total"], 6)
-        subject_term_counts = facet_results["subject"]["terms"]
+        self.assertEqual(aggregation_results["subject"]["total"], 6)
+        subject_term_counts = aggregation_results["subject"]["terms"]
         self.assertEqual(subject_term_counts["mathematics"], 3)
         self.assertEqual(subject_term_counts["history"], 1)
         self.assertEqual(subject_term_counts["physics"], 2)
 
-        self.assertEqual(facet_results["org"]["total"], 7)
-        org_term_counts = facet_results["org"]["terms"]
+        self.assertEqual(aggregation_results["org"]["total"], 7)
+        org_term_counts = aggregation_results["org"]["terms"]
         self.assertEqual(org_term_counts["edX"], 1)
         self.assertEqual(org_term_counts["MIT"], 2)
         self.assertEqual(org_term_counts["Harvard"], 4)
 
-    def test_filtered_faceted_search(self):
-        """ Test that faceting works well alongside filtered results """
-        self._index_for_facets()
+    def test_filtered_aggregation_search(self):
+        """ Test that aggregation works well alongside filtered results """
+        self._index_for_aggs()
 
-        facet_terms = {
+        aggregation_terms = {
             "subject": {},
             "org": {}
         }
-        response = self.searcher.search(field_dictionary={"org": "Harvard"}, facet_terms=facet_terms)
+        response = self.searcher.search(
+            field_dictionary={"org": "Harvard"},
+            aggregation_terms=aggregation_terms
+        )
         self.assertEqual(response["total"], 4)
-        self.assertIn("facets", response)
-        facet_results = response["facets"]
+        self.assertIn("aggs", response)
+        aggregation_results = response["aggs"]
 
-        self.assertEqual(facet_results["subject"]["total"], 3)
-        subject_term_counts = facet_results["subject"]["terms"]
+        self.assertEqual(aggregation_results["subject"]["total"], 3)
+        subject_term_counts = aggregation_results["subject"]["terms"]
         self.assertEqual(subject_term_counts["mathematics"], 1)
         self.assertEqual(subject_term_counts["history"], 1)
         self.assertEqual(subject_term_counts["physics"], 1)
 
-        self.assertEqual(facet_results["org"]["total"], 4)
-        org_term_counts = facet_results["org"]["terms"]
+        self.assertEqual(aggregation_results["org"]["total"], 4)
+        org_term_counts = aggregation_results["org"]["terms"]
         self.assertNotIn("edX", org_term_counts)
         self.assertNotIn("MIT", org_term_counts)
         self.assertEqual(org_term_counts["Harvard"], 4)
 
-        response = self.searcher.search(field_dictionary={"subject": ["physics", "history"]}, facet_terms=facet_terms)
+        response = self.searcher.search(
+            field_dictionary={"subject": ["physics", "history"]},
+            aggregation_terms=aggregation_terms
+        )
         self.assertEqual(response["total"], 3)
-        self.assertIn("facets", response)
-        facet_results = response["facets"]
+        self.assertIn("aggs", response)
+        aggregation_results = response["aggs"]
 
-        self.assertEqual(facet_results["subject"]["total"], 3)
-        subject_term_counts = facet_results["subject"]["terms"]
+        self.assertEqual(aggregation_results["subject"]["total"], 3)
+        subject_term_counts = aggregation_results["subject"]["terms"]
         self.assertNotIn("mathematics", subject_term_counts)
         self.assertEqual(subject_term_counts["history"], 1)
         self.assertEqual(subject_term_counts["physics"], 2)
 
-        self.assertEqual(facet_results["org"]["total"], 3)
-        org_term_counts = facet_results["org"]["terms"]
+        self.assertEqual(aggregation_results["org"]["total"], 3)
+        org_term_counts = aggregation_results["org"]["terms"]
         self.assertNotIn("edX", org_term_counts)
         self.assertEqual(org_term_counts["MIT"], 1)
         self.assertEqual(org_term_counts["Harvard"], 2)
